LogPanel class
A widget to show redirected logs from print.
Typically, LogPanel is used in combination with LogListenerScope or VerticalLogPanel. The height of LogPanel can be adjusted by dragging between minHeight and maxHeight.
listenable: LogValueNotifier which passed redirected logs from print to LogPanel.
If there is an ancestor LogListenerScope widget, listenable will be
not required, LogPanel will use the listenable provided by LogListenerScope.
itemBuilder: Redirected Logs will be shown in ListView, so itemBuilder is used for customizing
item appearance. _defaultItemBuilder will be used by default.
See also VerticalLogPanel.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- LogPanel
Constructors
- LogPanel({Key? key, required double minHeight, double maxHeight = double.infinity, LogValueNotifier? listenable, bool mergeDuplicateLogs = true, LogItemBuilder itemBuilder = LogPanel.defaultItemBuilder})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemBuilder → LogItemBuilder
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- listenable → LogValueNotifier?
-
final
- maxHeight → double
-
final
- mergeDuplicateLogs → bool
-
Merge adjacent duplicate logs
final
- minHeight → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → _LogPanelState -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
defaultItemBuilder(
BuildContext context, LogInfo logInfo, bool isFullScreen) → Widget